/*
 *  Copyright (c) 2017 - present, Architecode Corporation. All Rights Reserved.
 *
 *  This source code is licensed under the MIT License.
 *  The LICENSE file can be found in the root directory.
 *
 *  @cix-lic
*/


"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const OS = require("os");
const SEPARATOR = ":|:";
const UNKNOWN = "UNKNOWN";
class LoggerMetadata {
    constructor(metadata = {}, name, type, logger) {
        Object.defineProperties(this, {
            "Logger": {
                configurable: false,
                enumerable: true,
                writable: false,
                value: logger
            }
        });
        Object.assign(this, metadata);
        this.setAuthor(name, type);
    }
    setAuthor(name, type) {
        if (name && type) {
            this.Author = `${name}${SEPARATOR}${type}`;
        }
        else if (name) {
            this.Author = name;
        }
        else if (type) {
            this.Author = `${SEPARATOR}${type}`;
        }
        else {
            this.Author = UNKNOWN;
        }
    }
    pid() {
        return process.pid;
    }
    hostname() {
        return OS.hostname();
    }
    timestamp() {
        return new Date().toISOString();
    }
    static ofAuthor(author) {
        if (author == UNKNOWN) {
            return {};
        }
        else {
            const vals = author.split(SEPARATOR);
            const name = vals[0].length > 0 ? vals[0] : undefined;
            const type = vals[1];
            return { name, type };
        }
    }
}
exports.LoggerMetadata = LoggerMetadata;
